__name__ = 'drf_fsm'
__author__ = 'Neeraj Kumar'
__version__ = '1.0.4'
__author_email__ = 'sainineeraj1234@gmail.com'
__description__ = 'Create Django FSM transitions as a endpoint with Django REST Framework'
